package PureMessage::Monitor::EventHandler;

use strict;
use warnings;
use Carp;

# Creates a new "handler".
#
# Acceptable '%opts':
#   event       - Name/ID of event handled (REQUIRED)
#   logger      - Reference to logger object
sub new {
    my ($proto, $name, %opts) = @_;

    # create a new object from the provided opts
    my $class = ref($proto) || $proto;
    my $self  = {
        %opts,                  # handler options
        'name'  => $name,       # handler name
        };
    bless $self, $class;

    # sanity check parameters
    if (!$self->{'name'}) {
        croak "can't create un-named event handler";
    }
    if (!$self->{'event'}) {
        croak "can't create event handler '$name' without stating monitored events";
    }

    # return the newly created object back to the caller
    return $self;
}

# returns the handler name
sub name {
    return shift->{'name'};
}

# logs an event with the registered logger (if available)
sub log {
    my $self = shift;
    if ($self->{'logger'}) {
        $self->{'logger'}->log( @_ );
    }
}

# returns true if the handler is willing to accept the named event, returning
# false otherwise.
sub accepts_event {
    my ($self, $event_name) = @_;
    return 1 if (lc($self->{'event'}) eq 'all');
    return lc($event_name) eq lc($self->{'event'});
}

1;
