package PureMessage::Monitor::EventQueue;

use strict;
use warnings;
use Carp;
use PureMessage::Version qw($PREFIX);
use PureMessage::Monitor::Event;
use base qw( PureMessage::Monitor::EventQueue::dir );

our $QDIR_BASE = "$PREFIX/var/monitor/qdir";

# creates a new named event queue
sub new {
    my ($proto, $name, %opts) = @_;

    # sanity check arguments
    if (!$name) {
        croak "can't create un-named event queue";
    }

    # figure out the path to our queue directory
    my $path = "$QDIR_BASE/$name";

    # create a new object and bless it into our namespace
    my $class = ref($proto) || $proto;
    my $self  = $class->SUPER::new( $path, %opts );

    # return the newly created object back to the caller
    return $self;
}

1;

=head1 NAME

PureMessage::Monitor::EventQueue - Event queue for PureMessage Monitor

=head1 SYNOPSIS

  use PureMessage::Monitor::EventQueue;
  ...
  $queue = PureMessage::Monitor::EventQueue->new( 'queue_name', %opts );

  # see docs in PureMessage::Monitor::EventQueue::dir for more info

=head1 DESCRIPTION

C<PureMessage::Monitor::EventQueue> implements a simple event queue.

Please refer to the documentation for C<PureMessage::Monitor::EventQueue::dir>
for more information; right now we're just derived from that module (its the
only type of queue we have as of this writing).

=head1 SEE ALSO

L<PureMessage::Monitor::EventQueue::dir>.

=head1 COPYRIGHT

Copyright (C) 2000-2006 Sophos Group.  All rights reserved.  Sophos and
PureMessage are trademarks of Sophos Plc and Sophos Group.

=cut
