package PureMessage::Monitor::LogReader;

# Required inclusions.
use strict;
use warnings;
use PureMessage::Version qw($PREFIX);

# Derive ourselves from our base class.
use base qw( PureMessage::Reports::LogReader );

# OVER-RIDDEN METHOD.  Returns the path to the state file to be used for our
# log reader.
#
# Over-ridden so that we use a different state file than the standard message
# log consumer; although we consume the same log as a report consumer we need
# our state to be recorded in an entirely different place.
sub _state_file {
    my $self = shift;
    my $state_file_dir = "$PREFIX/var/monitor";
    return $state_file_dir . '/' . $self->type() . "_log_state.conf";
}

1;

=head1 NAME

PureMessage::Monitor::LogReader - log reader with state

=head1 SYNOPSIS

  # refer to PureMessage::Reports::LogReader

=head1 DESCRIPTION

C<PureMessage::Monitor::LogReader> implements a log reader that knows how to
pick up where it left off last time it read the log.

=head1 SEE ALSO

L<PureMessage::Reports::LogReader>.

=head1 COPYRIGHT

Copyright (C) 2000-2006 Sophos Group.  All rights reserved.  Sophos and
PureMessage are trademarks of Sophos Plc and Sophos Group.

=cut
